@@ -121,18 +121,18 @@ char* strins(const char* src,const char * pos,const char* ins)
 	* @retval E_UNKNOWN, if an error occurs
 	*	@retval	E_SUCCESS, otherwise
 */
-SINT32 getcurrentTimeMillis(BIGNUM* bnTime)
+/*SINT32 getcurrentTimeMillis(BIGNUM* bnTime)
 	{
 		if(bnTime==NULL)
 			return E_UNSPECIFIED;
 		#ifdef _WIN32
 			struct _timeb timebuffer;
 			_ftime(&timebuffer);
-			/* Hack what should be solved better...*/
+			// Hack what should be solved better...
 			BN_set_word(bnTime,timebuffer.time);
 			BN_mul_word(bnTime,1000);
 			BN_add_word(bnTime,timebuffer.millitm);
-			/* end of hack..*/
+			// end of hack..
 			return E_SUCCESS;
 	  #else //we dont use ftime due to a bug in glibc2.0
 		//we use gettimeofday() in order to get the millis...
@@ -143,15 +143,20 @@ SINT32 getcurrentTimeMillis(BIGNUM* bnTime)
 			BN_add_word(bnTime,tv.tv_usec/1000);
 			return E_SUCCESS;
 	  #endif
-	}
+	}*/
 
+/** Gets the current Systemtime in milli seconds. 
+	* @param u64Time - 64 bit Integer, in which the current time is placed
+	* @retval E_UNKNOWN, if an error occurs
+	*	@retval	E_SUCCESS, otherwise
+*/
 SINT32 getcurrentTimeMillis(UINT64& u64Time)
 	{
 		#ifdef _WIN32
 			struct _timeb timebuffer;
 			_ftime(&timebuffer);
 			/* Hack what should be solved better...*/
-			u64Time=timebuffer.time*1000+timebuffer.millitm;
+			u64Time=((UINT64)timebuffer.time)*1000+((UINT64)timebuffer.millitm);
 			/* end of hack..*/
 			return E_SUCCESS;
 	  #else //we dont use ftime due to a bug in glibc2.0
@@ -159,7 +164,7 @@ SINT32 getcurrentTimeMillis(UINT64& u64Time)
 			struct timeval tv;
 			gettimeofday(&tv,NULL); //getting millis...
 			#ifdef HAVE_NATIVE_UINT64
-				u64Time=tv.tv_sec*1000+tv.tv_usec/1000;
+				u64Time=((UINT64)tv.tv_sec)*1000+((UINT64)tv.tv_usec)/1000;
 				return E_SUCCESS;
 			#else
 				return E_UNKNOWN;
@@ -267,7 +272,7 @@ SINT32 setDOMElementValue(DOM_Element& elem,UINT32 text)
 		return E_SUCCESS;
 	}
 
-SINT32 setDOMElementValue(DOM_Element& elem,UINT8* value)
+SINT32 setDOMElementValue(DOM_Element& elem,const UINT8* value)
 	{
 		DOM_Text t=elem.getOwnerDocument().createTextNode(DOMString((char*)value));
 		//Remove all "old" text Elements...
@@ -282,30 +287,56 @@ SINT32 setDOMElementValue(DOM_Element& elem,UINT8* value)
 		return E_SUCCESS;
 	}
 
-SINT32 setDOMElementAttribute(DOM_Element& elem,char* attrName,UINT8* value)
+SINT32 setDOMElementAttribute(DOM_Node& elem,const char* attrName,const UINT8* value)
 	{
-		elem.setAttribute(attrName,DOMString((char*)value));
+		if(elem.isNull()||elem.getNodeType()!=DOM_Node::ELEMENT_NODE||
+				attrName==NULL||value==NULL)
+			return E_UNKNOWN;
+		static_cast<DOM_Element&>(elem).setAttribute(attrName,DOMString((const char*)value));
 		return E_SUCCESS;
 	}
 
-SINT32 setDOMElementAttribute(DOM_Element& elem,char* attrName,int value)
+SINT32 setDOMElementAttribute(DOM_Node& elem,const char* attrName,int value)
 	{
+		if(elem.isNull()||elem.getNodeType()!=DOM_Node::ELEMENT_NODE||
+				attrName==NULL)
+			return E_UNKNOWN;
 		UINT8 tmp[10];
 		sprintf((char*)tmp,"%i",value);
-		elem.setAttribute(attrName,DOMString((char*)tmp));
+		static_cast<DOM_Element&>(elem).setAttribute(attrName,DOMString((char*)tmp));
 		return E_SUCCESS;
 	}
 
-SINT32 getDOMElementAttribute(DOM_Element& elem,char* attrName,int* value)
+SINT32 getDOMElementAttribute(const DOM_Element& elem,const char* attrName,int* value)
 	{
 		if(elem==NULL||attrName==NULL||value==NULL)
 			return E_UNKNOWN;
 		char* tmpStr=elem.getAttribute(attrName).transcode();
 		*value=atol(tmpStr);
-		delete tmpStr;
+		delete[] tmpStr;
 		return E_SUCCESS;
 	}
 
+SINT32 getDOMElementAttribute(const DOM_Node& elem,const char* attrName,bool& value)
+	{
+		if(	elem==NULL||elem.getNodeType()!=DOM_Node::ELEMENT_NODE||
+				attrName==NULL)
+			return E_UNKNOWN;
+		SINT32 ret=E_UNSPECIFIED;
+		char* tmpStr=static_cast<const DOM_Element&>(elem).getAttribute(attrName).transcode();
+		if(stricmp(tmpStr,"true")==0)
+			{
+				value=true;
+				ret=E_SUCCESS;
+			}
+		else if(stricmp(tmpStr,"false")==0)
+			{
+				value=false;
+				ret=E_SUCCESS;
+			}
+		delete[] tmpStr;
+		return ret;
+	}
 SINT32 getDOMChildByName(const DOM_Node& node,const UINT8* const name,DOM_Node& child,bool deep)
 	{
 		if(node==NULL)
@@ -327,7 +358,7 @@ SINT32 getDOMChildByName(const DOM_Node& node,const UINT8* const name,DOM_Node&
 		return E_UNKNOWN;
 	}
 
-SINT32 getDOMElementValue(DOM_Node& elem,UINT8* value,UINT32* valuelen)
+SINT32 getDOMElementValue(const DOM_Node& elem,UINT8* value,UINT32* valuelen)
 	{
 		ASSERT(value!=NULL,"Value is null");
 		ASSERT(valuelen!=NULL,"ValueLen is null");
@@ -359,7 +390,7 @@ SINT32 getDOMElementValue(DOM_Node& elem,UINT8* value,UINT32* valuelen)
 		return E_SUCCESS;
 	}
 
-SINT32 getDOMElementValue(DOM_Element& elem,UINT32* value)
+SINT32 getDOMElementValue(const DOM_Element& elem,UINT32* value)
 	{
 		ASSERT(value!=NULL,"Value is null");
 		ASSERT(!elem.isNull,"Element is NULL");
@@ -372,7 +403,7 @@ SINT32 getDOMElementValue(DOM_Element& elem,UINT32* value)
 		return E_SUCCESS;
 	}
 
-SINT32 getDOMElementValue(DOM_Element& elem,UINT16* value)
+SINT32 getDOMElementValue(const DOM_Element& elem,UINT16* value)
 	{
 		UINT32 tmp;
 		if(getDOMElementValue(elem,&tmp)!=E_SUCCESS)
@@ -383,6 +414,7 @@ SINT32 getDOMElementValue(DOM_Element& elem,UINT16* value)
 		return E_SUCCESS;
 	}
 
+
 void __encryptKey(UINT8* key,UINT32 keylen,UINT8* outBuff,UINT32* outLen,CAASymCipher* pRSA)
 	{
 		UINT8 tmpBuff[1024];
